@@ -4,7 +4,7 @@ from blueness import module
 from blueness.argparse.generic import sys_exit
 
 from bluer_ugv import NAME
-from bluer_ugv.swallow.dataset.collection import collect
+from bluer_ugv.swallow.dataset.combination import combine
 from bluer_ugv.logger import logger
 
 NAME = module.name(__file__, NAME)
@@ -13,7 +13,7 @@ parser = argparse.ArgumentParser(NAME)
 parser.add_argument(
     "task",
     type=str,
-    help="collect",
+    help="combine",
 )
 parser.add_argument(
     "--count",
@@ -31,20 +31,39 @@ parser.add_argument(
     type=str,
 )
 parser.add_argument(
-    "--update_metadata",
+    "--recent",
     type=int,
-    default=0,
+    default=1,
     help="0 | 1",
 )
+parser.add_argument(
+    "--split",
+    type=int,
+    default=1,
+    help="0 | 1",
+)
+parser.add_argument(
+    "--test_ratio",
+    type=float,
+    default=0.1,
+)
+parser.add_argument(
+    "--train_ratio",
+    type=float,
+    default=0.8,
+)
 args = parser.parse_args()
 
 success = False
-if args.task == "collect":
-    success = collect(
+if args.task == "combine":
+    success = combine(
         object_name=args.object_name,
         count=args.count,
         download=args.download == 1,
-        update_metadata=args.update_metadata == 1,
+        recent=args.recent == 1,
+        split=args.split == 1,
+        test_ratio=args.test_ratio,
+        train_ratio=args.train_ratio,
     )
 else:
     success = None
